@@ -62,15 +62,7 @@ FAKE_ENV4 = {'OS_USER_ID': 'user_id',
 FAKE_ENV5 = {'OS_USERNAME': 'username',
              'OS_PASSWORD': 'password',
              'OS_TENANT_NAME': 'tenant_name',
-             'OS_AUTH_URL': 'http://no.where/v2.0',
-             'OS_COMPUTE_API_VERSION': '2',
-             'OS_AUTH_SYSTEM': 'rackspace'}
-
-FAKE_ENV6 = {'OS_USERNAME': 'username',
-             'OS_PASSWORD': 'password',
-             'OS_TENANT_NAME': 'tenant_name',
-             'OS_AUTH_URL': 'http://no.where/v2.0',
-             'OS_AUTH_SYSTEM': 'rackspace'}
+             'OS_AUTH_URL': 'http://no.where/v2.0'}
 
 
 def _create_ver_list(versions):
@@ -181,7 +173,7 @@ class DeprecatedActionTest(utils.TestCase):
 
         self.assertEqual(result.emitted, set())
         self.assertIsNone(result.use)
-        self.assertEqual(result.real_action_args, False)
+        self.assertIs(result.real_action_args, False)
         self.assertIsNone(result.real_action)
         mock_init.assert_called_once_with(
             'option_strings', 'dest', help='Deprecated', a=1, b=2, c=3)
@@ -208,7 +200,7 @@ class DeprecatedActionTest(utils.TestCase):
 
         self.assertEqual(result.emitted, set())
         self.assertIsNone(result.use)
-        self.assertEqual(result.real_action_args, False)
+        self.assertIs(result.real_action_args, False)
         self.assertEqual(result.real_action, action.return_value)
         mock_init.assert_called_once_with(
             'option_strings', 'dest', help='Deprecated', a=1, b=2, c=3)
@@ -467,8 +459,8 @@ class ShellTest(utils.TestCase):
             '.*--matching',
             '.*--wrap',
             '.*help',
-            '.*secgroup-delete-rule',
-            '.*--priority']
+            '.*server-group-delete',
+            '.*--image-with']
         for r in required:
             self.assertThat((stdout + stderr),
                             matchers.MatchesRegex(r, re.DOTALL | re.MULTILINE))
@@ -519,9 +511,7 @@ class ShellTest(utils.TestCase):
 
     def test_no_auth_url(self):
         required = ('You must provide an auth url'
-                    ' via either --os-auth-url or env[OS_AUTH_URL] or'
-                    ' specify an auth_system which defines a default url'
-                    ' with --os-auth-system or env[OS_AUTH_SYSTEM]',)
+                    ' via either --os-auth-url or env[OS_AUTH_URL].',)
         self.make_env(exclude='OS_AUTH_URL')
         try:
             self.shell('list')
@@ -607,21 +597,17 @@ class ShellTest(utils.TestCase):
         if version is None:
             cmd = 'list'
         else:
-            cmd = ('--service_type %s --os-compute-api-version %s list' %
+            cmd = ('--service-type %s --os-compute-api-version %s list' %
                    (service_type, version))
         self.make_env()
         self.shell(cmd)
-        _, client_kwargs = mock_client.call_args_list[0]
+        _client_args, client_kwargs = mock_client.call_args_list[0]
         self.assertEqual(service_type, client_kwargs['service_type'])
 
     @mock.patch('novaclient.client.Client')
     def test_default_service_type(self, mock_client):
         self._test_service_type(None, 'compute', mock_client)
 
-    @mock.patch('novaclient.client.Client')
-    def test_v1_1_service_type(self, mock_client):
-        self._test_service_type('1.1', 'compute', mock_client)
-
     @mock.patch('novaclient.client.Client')
     def test_v2_service_type(self, mock_client):
         self._test_service_type('2', 'compute', mock_client)
@@ -665,6 +651,27 @@ class ShellTest(utils.TestCase):
         exc = self.assertRaises(RuntimeError, self.shell, '--timings list')
         self.assertEqual('Boom!', str(exc))
 
+    @requests_mock.Mocker()
+    def test_osprofiler(self, m_requests):
+        self.make_env()
+
+        def client(*args, **kwargs):
+            self.assertEqual('swordfish', kwargs['profile'])
+        with mock.patch('novaclient.client.Client', client):
+            # we are only interested in the fact Client is initialized properly
+            self.shell('list --profile swordfish', (0, 2))
+
+    @requests_mock.Mocker()
+    def test_osprofiler_not_installed(self, m_requests):
+        self.make_env()
+
+        # NOTE(rpodolyaka): osprofiler is in test-requirements, so we have to
+        # simulate its absence here
+        with mock.patch('novaclient.shell.osprofiler_profiler', None):
+            _, stderr = self.shell('list --profile swordfish', (0, 2))
+            self.assertIn('unrecognized arguments: --profile swordfish',
+                          stderr)
+
     @mock.patch('novaclient.shell.SecretsHelper.tenant_id',
                 return_value=True)
     @mock.patch('novaclient.shell.SecretsHelper.auth_token',
@@ -687,7 +694,7 @@ class ShellTest(utils.TestCase):
 
     @mock.patch('novaclient.client.Client')
     def test_microversion_with_default_behaviour(self, mock_client):
-        self.make_env(fake_env=FAKE_ENV6)
+        self.make_env(fake_env=FAKE_ENV5)
         self.mock_server_version_range.return_value = (
             api_versions.APIVersion("2.1"), api_versions.APIVersion("2.3"))
         self.shell('list')
@@ -697,7 +704,7 @@ class ShellTest(utils.TestCase):
     @mock.patch('novaclient.client.Client')
     def test_microversion_with_default_behaviour_with_legacy_server(
             self, mock_client):
-        self.make_env(fake_env=FAKE_ENV6)
+        self.make_env(fake_env=FAKE_ENV5)
         self.mock_server_version_range.return_value = (
             api_versions.APIVersion(), api_versions.APIVersion())
         self.shell('list')
@@ -777,15 +784,6 @@ class ShellTest(utils.TestCase):
             self.shell,
             '--os-compute-api-version 2.3 list')
 
-    @mock.patch('novaclient.client.Client')
-    def test_custom_auth_plugin(self, mock_client):
-        self.make_env(fake_env=FAKE_ENV5)
-        self.shell('list')
-        password = mock_client.call_args_list[0][0][2]
-        client_kwargs = mock_client.call_args_list[0][1]
-        self.assertEqual(password, 'password')
-        self.assertIs(client_kwargs['session'], None)
-
     @mock.patch.object(novaclient.shell.OpenStackComputeShell, 'main')
     def test_main_error_handling(self, mock_compute_shell):
         class MyException(Exception):
